==> osidb_bindings-4.10.1.tar.gz: osidb_bindings-4.10.1/osidb_bindings/bindings/python_client/api/osidb/osidb_api_v1_trackers_update.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.osidb_api_v1_trackers_update_response_200 import (
    OsidbApiV1TrackersUpdateResponse200,
)
from ...models.tracker_request import TrackerRequest
from ...types import UNSET, Response, Unset, check_nested_instance

QUERY_PARAMS = {}

REQUEST_BODY_TYPE = TrackerRequest


def _get_kwargs(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerRequest,
        TrackerRequest,
        TrackerRequest,
    ],
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/trackers/{uuid}".format(
            uuid=uuid,
        ),
    }

    if check_nested_instance(body, TrackerRequest):
        _json_body: dict[str, Any] = UNSET
        if not isinstance(body, Unset):
            _json_body = body.to_dict()

        _kwargs["json"] = _json_body
        headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1TrackersUpdateResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1TrackersUpdateResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1TrackersUpdateResponse200.from_dict(_response_200)

        return response_200


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1TrackersUpdateResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerRequest,
        TrackerRequest,
        TrackerRequest,
    ],
) -> Response[OsidbApiV1TrackersUpdateResponse200]:
    """
    Args:
        uuid (UUID):
        bugzilla_api_key (str):
        jira_api_key (str):
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1TrackersUpdateResponse200]
    """

    kwargs = _get_kwargs(
        uuid=uuid,
        client=client,
        body=body,
    )

    response = requests.put(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerRequest,
        TrackerRequest,
        TrackerRequest,
    ],
) -> Optional[OsidbApiV1TrackersUpdateResponse200]:
    """
    Args:
        uuid (UUID):
        bugzilla_api_key (str):
        jira_api_key (str):
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1TrackersUpdateResponse200
    """

    return sync_detailed(
        uuid=uuid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerRequest,
        TrackerRequest,
        TrackerRequest,
    ],
) -> Response[OsidbApiV1TrackersUpdateResponse200]:
    """
    Args:
        uuid (UUID):
        bugzilla_api_key (str):
        jira_api_key (str):
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1TrackersUpdateResponse200]
    """

    kwargs = _get_kwargs(
        uuid=uuid,
        client=client,
        body=body,
    )

    async with client.get_async_session().put(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerRequest,
        TrackerRequest,
        TrackerRequest,
    ],
) -> Optional[OsidbApiV1TrackersUpdateResponse200]:
    """
    Args:
        uuid (UUID):
        bugzilla_api_key (str):
        jira_api_key (str):
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer
        body (TrackerRequest): Tracker serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1TrackersUpdateResponse200
    """

    return (
        await asyncio_detailed(
            uuid=uuid,
            client=client,
            body=body,
        )
    ).parsed

==> osidb_bindings-5.0.0b3.tar.gz: osidb_bindings-5.0.0b3/osidb_bindings/bindings/python_client/api/osidb/osidb_api_v1_trackers_update.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.osidb_api_v1_trackers_update_response_200 import (
    OsidbApiV1TrackersUpdateResponse200,
)
from ...models.tracker_v1_request import TrackerV1Request
from ...types import UNSET, Response, Unset, check_nested_instance

QUERY_PARAMS = {}

REQUEST_BODY_TYPE = TrackerV1Request


def _get_kwargs(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerV1Request,
        TrackerV1Request,
        TrackerV1Request,
    ],
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/trackers/{uuid}".format(
            uuid=uuid,
        ),
    }

    if check_nested_instance(body, TrackerV1Request):
        _json_body: dict[str, Any] = UNSET
        if not isinstance(body, Unset):
            _json_body = body.to_dict()

        _kwargs["json"] = _json_body
        headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1TrackersUpdateResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1TrackersUpdateResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1TrackersUpdateResponse200.from_dict(_response_200)

        return response_200


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1TrackersUpdateResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerV1Request,
        TrackerV1Request,
        TrackerV1Request,
    ],
) -> Response[OsidbApiV1TrackersUpdateResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        uuid (UUID):
        bugzilla_api_key (Union[Unset, str]):
        jira_api_key (Union[Unset, str]):
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1TrackersUpdateResponse200]
    """

    kwargs = _get_kwargs(
        uuid=uuid,
        client=client,
        body=body,
    )

    response = requests.put(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerV1Request,
        TrackerV1Request,
        TrackerV1Request,
    ],
) -> Optional[OsidbApiV1TrackersUpdateResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        uuid (UUID):
        bugzilla_api_key (Union[Unset, str]):
        jira_api_key (Union[Unset, str]):
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1TrackersUpdateResponse200
    """

    return sync_detailed(
        uuid=uuid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerV1Request,
        TrackerV1Request,
        TrackerV1Request,
    ],
) -> Response[OsidbApiV1TrackersUpdateResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        uuid (UUID):
        bugzilla_api_key (Union[Unset, str]):
        jira_api_key (Union[Unset, str]):
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1TrackersUpdateResponse200]
    """

    kwargs = _get_kwargs(
        uuid=uuid,
        client=client,
        body=body,
    )

    async with client.get_async_session().put(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    uuid: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        TrackerV1Request,
        TrackerV1Request,
        TrackerV1Request,
    ],
) -> Optional[OsidbApiV1TrackersUpdateResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        uuid (UUID):
        bugzilla_api_key (Union[Unset, str]):
        jira_api_key (Union[Unset, str]):
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1
        body (TrackerV1Request): Serializer for the tracker model adapted to affects v1

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1TrackersUpdateResponse200
    """

    return (
        await asyncio_detailed(
            uuid=uuid,
            client=client,
            body=body,
        )
    ).parsed
